summaryrefslogtreecommitdiffstats
path: root/kjsembed/builtins
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:20:48 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:20:48 -0600
commite63beeb5bdb82987b1e00bc35178667786fbad48 (patch)
treeab77b6ac830b7944d5d1eb9ce8f81feb8fdab948 /kjsembed/builtins
parent67557a2b56c0678c22ab1b00c4fd0224c5e9ed99 (diff)
downloadtdebindings-e63beeb5bdb82987b1e00bc35178667786fbad48.tar.gz
tdebindings-e63beeb5bdb82987b1e00bc35178667786fbad48.zip
Fix incorrect conversion
Diffstat (limited to 'kjsembed/builtins')
-rw-r--r--kjsembed/builtins/qdir_imp.cpp136
-rw-r--r--kjsembed/builtins/qdir_imp.h6
-rw-r--r--kjsembed/builtins/qfile_imp.cpp48
-rw-r--r--kjsembed/builtins/qfile_imp.h8
-rw-r--r--kjsembed/builtins/resources.cpp52
-rw-r--r--kjsembed/builtins/resources.h4
-rw-r--r--kjsembed/builtins/saxhandler.cpp28
-rw-r--r--kjsembed/builtins/saxhandler.h10
-rw-r--r--kjsembed/builtins/stdaction_imp.cpp6
-rw-r--r--kjsembed/builtins/stddialog_imp.cpp16
-rw-r--r--kjsembed/builtins/textstream_imp.cpp14
-rw-r--r--kjsembed/builtins/textstream_imp.h6
12 files changed, 167 insertions, 167 deletions
diff --git a/kjsembed/builtins/qdir_imp.cpp b/kjsembed/builtins/qdir_imp.cpp
index 4a1d6bde..6d4f674f 100644
--- a/kjsembed/builtins/qdir_imp.cpp
+++ b/kjsembed/builtins/qdir_imp.cpp
@@ -26,10 +26,10 @@ namespace Bindings {
{
JSOpaqueProxy * prx;
if ( args.size() == 0 ) {
- prx = new JSOpaqueProxy( new TTQDir( TTQDir::current() ), "TTQDir" );
+ prx = new JSOpaqueProxy( new TQDir( TQDir::current() ), "TQDir" );
} else {
- TTQString arg0 = ( args.size() >= 1 ) ? args[ 0 ].toString( exec ).qstring() : TTQString::null;
- prx = new JSOpaqueProxy( new TTQDir( arg0 ), "TTQDir" );
+ TQString arg0 = ( args.size() >= 1 ) ? args[ 0 ].toString( exec ).qstring() : TQString::null;
+ prx = new JSOpaqueProxy( new TQDir( arg0 ), "TQDir" );
}
prx->setOwner( JSProxy::JavaScript );
KJS::Object proxyObj( prx );
@@ -44,12 +44,12 @@ namespace Bindings {
}
-TTQDirImp::TQDirImp( KJS::ExecState *exec, int id )
+TQDirImp::TQDirImp( KJS::ExecState *exec, int id )
: JSProxyImp(exec), mid(id)
{
}
-TTQDirImp::~TQDirImp()
+TQDirImp::~TQDirImp()
{
}
@@ -177,31 +177,31 @@ void TQDirImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
EnumValue enums[] = {
// enum FilterSpec
- { "Dirs", TTQDir::Dirs },
- { "Files", TTQDir::Files },
- { "Drives", TTQDir::Drives },
- { "NoSymLinks", TTQDir::NoSymLinks },
- { "All", TTQDir::All },
- { "TypeMask", TTQDir::TypeMask },
- { "Readable", TTQDir::Readable },
- { "Writable", TTQDir::Writable },
- { "Executable", TTQDir::Executable },
- { "RWEMask", TTQDir::RWEMask },
- { "Modified", TTQDir::Modified },
- { "Hidden", TTQDir::Hidden },
- { "System", TTQDir::System },
- { "AccessMask", TTQDir::AccessMask },
- { "DefaultFilter", TTQDir::DefaultFilter },
+ { "Dirs", TQDir::Dirs },
+ { "Files", TQDir::Files },
+ { "Drives", TQDir::Drives },
+ { "NoSymLinks", TQDir::NoSymLinks },
+ { "All", TQDir::All },
+ { "TypeMask", TQDir::TypeMask },
+ { "Readable", TQDir::Readable },
+ { "Writable", TQDir::Writable },
+ { "Executable", TQDir::Executable },
+ { "RWEMask", TQDir::RWEMask },
+ { "Modified", TQDir::Modified },
+ { "Hidden", TQDir::Hidden },
+ { "System", TQDir::System },
+ { "AccessMask", TQDir::AccessMask },
+ { "DefaultFilter", TQDir::DefaultFilter },
// enum SortSpec
- { "Name", TTQDir::Name },
- { "Time", TTQDir::Time },
- { "Size", TTQDir::Size },
- { "Unsorted", TTQDir::Unsorted },
- { "SortByMask", TTQDir::SortByMask },
- { "DirsFirst", TTQDir::DirsFirst },
- { "Reversed", TTQDir::Reversed },
- { "IgnoreCase", TTQDir::IgnoreCase },
- { "DefaultSort", TTQDir::DefaultSort },
+ { "Name", TQDir::Name },
+ { "Time", TQDir::Time },
+ { "Size", TQDir::Size },
+ { "Unsorted", TQDir::Unsorted },
+ { "SortByMask", TQDir::SortByMask },
+ { "DirsFirst", TQDir::DirsFirst },
+ { "Reversed", TQDir::Reversed },
+ { "IgnoreCase", TQDir::IgnoreCase },
+ { "DefaultSort", TQDir::DefaultSort },
{ 0, 0 }
};
@@ -222,12 +222,12 @@ KJS::Value TQDirImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::L
return KJS::Value();
}
- if ( op->typeName() != "TTQDir" ) {
+ if ( op->typeName() != "TQDir" ) {
kdWarning() << "TQDirImp::call() failed, type is " << op->typeName() << endl;
return KJS::Value();
}
- instance = op->toNative<TTQDir>();
+ instance = op->toNative<TQDir>();
switch( mid ) {
@@ -431,7 +431,7 @@ KJS::Value TQDirImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::L
break;
}
- TTQString msg = i18n( "TQDirImp has no method with id '%1'." ).arg( mid );
+ TQString msg = i18n( "TQDirImp has no method with id '%1'." ).arg( mid );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -439,7 +439,7 @@ KJS::Value TQDirImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::L
KJS::Value TQDirImp::setPath_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->setPath(
arg0 );
@@ -450,7 +450,7 @@ KJS::Value TQDirImp::setPath_7( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value TQDirImp::path_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->path( );
return KJS::String( ret );
@@ -459,7 +459,7 @@ KJS::Value TQDirImp::path_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::
KJS::Value TQDirImp::absPath_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->absPath( );
return KJS::String( ret );
@@ -468,7 +468,7 @@ KJS::Value TQDirImp::absPath_9( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value TQDirImp::canonicalPath_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->canonicalPath( );
return KJS::String( ret );
@@ -477,7 +477,7 @@ KJS::Value TQDirImp::canonicalPath_10( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQDirImp::dirName_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->dirName( );
return KJS::String( ret );
@@ -486,11 +486,11 @@ KJS::Value TQDirImp::dirName_11( KJS::ExecState *exec, KJS::Object &obj, const K
KJS::Value TQDirImp::filePath_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
- TTQString ret;
+ TQString ret;
ret = instance->filePath(
arg0,
arg1 );
@@ -501,11 +501,11 @@ KJS::Value TQDirImp::filePath_12( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQDirImp::absFilePath_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
- TTQString ret;
+ TQString ret;
ret = instance->absFilePath(
arg0,
arg1 );
@@ -516,7 +516,7 @@ KJS::Value TQDirImp::absFilePath_13( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQDirImp::cd_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -540,7 +540,7 @@ KJS::Value TQDirImp::cdUp_15( KJS::ExecState *exec, KJS::Object &obj, const KJS:
KJS::Value TQDirImp::nameFilter_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->nameFilter( );
return KJS::String( ret );
@@ -549,7 +549,7 @@ KJS::Value TQDirImp::nameFilter_16( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQDirImp::setNameFilter_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->setNameFilter(
arg0 );
@@ -641,7 +641,7 @@ KJS::Value TQDirImp::encodedEntryList_26( KJS::ExecState *exec, KJS::Object &obj
KJS::Value TQDirImp::encodedEntryList_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
@@ -662,7 +662,7 @@ KJS::Value TQDirImp::entryList_28( KJS::ExecState *exec, KJS::Object &obj, const
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
- TTQStringList ret;
+ TQStringList ret;
ret = instance->entryList(
arg0,
arg1 );
@@ -674,13 +674,13 @@ KJS::Value TQDirImp::entryList_28( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQDirImp::entryList_29( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
int arg2 = (args.size() >= 3) ? args[2].toInteger(exec) : -1;
- TTQStringList ret;
+ TQStringList ret;
ret = instance->entryList(
arg0,
arg1,
@@ -707,7 +707,7 @@ KJS::Value TQDirImp::entryInfoList_30( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQDirImp::entryInfoList_31( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
@@ -724,7 +724,7 @@ KJS::Value TQDirImp::entryInfoList_31( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQDirImp::mkdir_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -739,7 +739,7 @@ KJS::Value TQDirImp::mkdir_32( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value TQDirImp::rmdir_33( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -798,7 +798,7 @@ KJS::Value TQDirImp::convertToAbs_38( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value TQDirImp::remove_41( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -813,9 +813,9 @@ KJS::Value TQDirImp::remove_41( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value TQDirImp::rename_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- TTQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TTQString::null;
+ TQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TQString::null;
bool arg2 = (args.size() >= 3) ? args[2].toBoolean(exec) : false;
@@ -831,7 +831,7 @@ KJS::Value TQDirImp::rename_42( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value TQDirImp::exists_43( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -854,9 +854,9 @@ KJS::Value TQDirImp::refresh_44( KJS::ExecState *exec, KJS::Object &obj, const K
KJS::Value TQDirImp::convertSeparators_45( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- TTQString ret;
+ TQString ret;
ret = instance->convertSeparators(
arg0 );
return KJS::String( ret );
@@ -882,7 +882,7 @@ KJS::Value TQDirImp::separator_47( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQDirImp::setCurrent_48( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->setCurrent(
@@ -918,7 +918,7 @@ KJS::Value TQDirImp::root_51( KJS::ExecState *exec, KJS::Object &obj, const KJS:
KJS::Value TQDirImp::currentDirPath_52( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->currentDirPath( );
return KJS::String( ret );
@@ -927,7 +927,7 @@ KJS::Value TQDirImp::currentDirPath_52( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQDirImp::homeDirPath_53( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->homeDirPath( );
return KJS::String( ret );
@@ -936,7 +936,7 @@ KJS::Value TQDirImp::homeDirPath_53( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQDirImp::rootDirPath_54( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->rootDirPath( );
return KJS::String( ret );
@@ -945,12 +945,12 @@ KJS::Value TQDirImp::rootDirPath_54( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQDirImp::match_55( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQStringList arg0;
+ TQStringList arg0;
if ( args.size() >= 1 ) {
// TODO: populate the list
}
- TTQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TTQString::null;
+ TQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->match(
@@ -963,9 +963,9 @@ KJS::Value TQDirImp::match_55( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value TQDirImp::match_56( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- TTQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TTQString::null;
+ TQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->match(
@@ -978,9 +978,9 @@ KJS::Value TQDirImp::match_56( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value TQDirImp::cleanDirPath_57( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- TTQString ret;
+ TQString ret;
ret = instance->cleanDirPath(
arg0 );
return KJS::String( ret );
@@ -990,7 +990,7 @@ KJS::Value TQDirImp::cleanDirPath_57( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value TQDirImp::isRelativePath_58( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->isRelativePath(
diff --git a/kjsembed/builtins/qfile_imp.cpp b/kjsembed/builtins/qfile_imp.cpp
index 85d2fc6b..7f3d2b5b 100644
--- a/kjsembed/builtins/qfile_imp.cpp
+++ b/kjsembed/builtins/qfile_imp.cpp
@@ -25,12 +25,12 @@
*/
namespace KJSEmbed {
-TTQFileImp::TQFileImp( KJS::ExecState *exec, int mid, bool constructor )
+TQFileImp::TQFileImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQFileImp::~TQFileImp()
+TQFileImp::~TQFileImp()
{
}
@@ -71,7 +71,7 @@ void TQFileImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
do {
if ( lastName != methods[idx].name ) {
@@ -85,23 +85,23 @@ void TQFileImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
-TTQFile *TQFileImp::toTQFile( KJS::Object &self )
+TQFile *TQFileImp::toTQFile( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQFile *>( obj );
+ return dynamic_cast<TQFile *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TTQFile" )
+ if ( op->typeName() != "TQFile" )
return 0;
- return op->toNative<TTQFile>();
+ return op->toNative<TQFile>();
}
@@ -121,7 +121,7 @@ KJS::Object TQFileImp::construct( KJS::ExecState *exec, const KJS::List &args )
break;
}
- TTQString msg = i18n("TQFileCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("TQFileCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -135,7 +135,7 @@ KJS::Object TQFileImp::TQFile_2( KJS::ExecState *exec, const KJS::List &args )
{
// TODO
- TTQWidget *arg0 = 0L;
+ TQWidget *arg0 = 0L;
return KJS::Object();
}
@@ -266,7 +266,7 @@ KJS::Value TQFileImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::
break;
}
- TTQString msg = i18n( "TQFileImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "TQFileImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg, KJS::ReferenceError );
}
@@ -274,7 +274,7 @@ KJS::Value TQFileImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::
KJS::Value TQFileImp::name_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->name( );
return KJS::String( ret );
@@ -283,7 +283,7 @@ KJS::Value TQFileImp::name_4( KJS::ExecState *exec, KJS::Object &obj, const KJS:
KJS::Value TQFileImp::setName_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->setName(
arg0 );
@@ -389,7 +389,7 @@ KJS::Value TQFileImp::at_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::
KJS::Value TQFileImp::at_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQFile::Offset arg0 = 0; // TODO (hack for qfile)
+ TQFile::Offset arg0 = 0; // TODO (hack for qfile)
bool ret;
ret = instance->at(
@@ -447,7 +447,7 @@ KJS::Value TQFileImp::writeBlock_18( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQFileImp::writeBlock_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQByteArray arg0; // TODO (hack for qfile)
+ TQByteArray arg0; // TODO (hack for qfile)
instance->writeBlock(
arg0 );
@@ -478,7 +478,7 @@ KJS::Value TQFileImp::readLine_20( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQFileImp::readLine_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
// Unsupported parameter Q_ULONG
return KJS::Value();
@@ -537,7 +537,7 @@ KJS::Value TQFileImp::handle_25( KJS::ExecState *exec, KJS::Object &obj, const K
KJS::Value TQFileImp::errorString_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->errorString( );
return KJS::String( ret );
@@ -546,7 +546,7 @@ KJS::Value TQFileImp::errorString_26( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value TQFileImp::encodeName_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->encodeName(
arg0 );
@@ -557,9 +557,9 @@ KJS::Value TQFileImp::encodeName_27( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQFileImp::decodeName_28( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- const TTQCString arg0 = (args.size() >= 1) ? args[0].toString(exec).ascii() : 0;
+ const TQCString arg0 = (args.size() >= 1) ? args[0].toString(exec).ascii() : 0;
- TTQString ret;
+ TQString ret;
ret = instance->decodeName(
arg0 );
return KJS::String( ret );
@@ -569,7 +569,7 @@ KJS::Value TQFileImp::decodeName_28( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQFileImp::setEncodingFunction_29( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQFile::EncoderFn arg0 = 0; // TODO (hack for qfile)
+ TQFile::EncoderFn arg0 = 0; // TODO (hack for qfile)
instance->setEncodingFunction(
arg0 );
@@ -580,7 +580,7 @@ KJS::Value TQFileImp::setEncodingFunction_29( KJS::ExecState *exec, KJS::Object
KJS::Value TQFileImp::setDecodingFunction_30( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQFile::DecoderFn arg0 = 0; // TODO (hack for qfile)
+ TQFile::DecoderFn arg0 = 0; // TODO (hack for qfile)
instance->setDecodingFunction(
arg0 );
@@ -591,7 +591,7 @@ KJS::Value TQFileImp::setDecodingFunction_30( KJS::ExecState *exec, KJS::Object
KJS::Value TQFileImp::exists_31( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->exists(
@@ -603,7 +603,7 @@ KJS::Value TQFileImp::exists_31( KJS::ExecState *exec, KJS::Object &obj, const K
KJS::Value TQFileImp::remove_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->remove(
diff --git a/kjsembed/builtins/qfile_imp.h b/kjsembed/builtins/qfile_imp.h
index 6db9b2df..69d28e9d 100644
--- a/kjsembed/builtins/qfile_imp.h
+++ b/kjsembed/builtins/qfile_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TTQFile;
+class TQFile;
/**
* Namespace containing the KJSEmbed library.
@@ -17,7 +17,7 @@ class TTQFile;
namespace KJSEmbed {
/**
- * Wrapper class for TTQFile methods.
+ * Wrapper class for TQFile methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -72,7 +72,7 @@ public:
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TTQFile *toTQFile( KJS::Object &object );
+ static TQFile *toTQFile( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -132,7 +132,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQFile *instance; // Temp
+ TQFile *instance; // Temp
int id;
bool cons;
};
diff --git a/kjsembed/builtins/resources.cpp b/kjsembed/builtins/resources.cpp
index 40ffdcd2..192b17fa 100644
--- a/kjsembed/builtins/resources.cpp
+++ b/kjsembed/builtins/resources.cpp
@@ -70,75 +70,75 @@ void StdDirsImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
KJS::Value StdDirsImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, const KJS::List &args )
{
-// TTQString arg0 = extractTQString(exec, args, 0);
-// TTQString arg1 = extractTQString(exec, args, 1);
+// TQString arg0 = extractTQString(exec, args, 0);
+// TQString arg1 = extractTQString(exec, args, 1);
switch( id ) {
case StdDirsImp::findResource:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
- TTQString path = KGlobal::dirs ()->findResource(arg0.latin1(), arg1);
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString arg1 = extractTQString(exec, args, 1);
+ TQString path = KGlobal::dirs ()->findResource(arg0.latin1(), arg1);
return KJS::String( path );
}
case StdDirsImp::addResourceType:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString arg1 = extractTQString(exec, args, 1);
bool isOk = KGlobal::dirs ()->addResourceType(arg0.latin1(), arg1);
return KJS::Boolean( isOk );
}
case StdDirsImp::kde_default:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString path = KGlobal::dirs ()->kde_default(arg0.latin1());
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString path = KGlobal::dirs ()->kde_default(arg0.latin1());
return KJS::String( path );
}
case StdDirsImp::addResourceDir:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString arg1 = extractTQString(exec, args, 1);
bool isOk = KGlobal::dirs ()->addResourceDir(arg0.latin1(), arg1);
return KJS::Boolean( isOk );
}
case StdDirsImp::findResourceDir:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
- TTQString path = KGlobal::dirs ()->findResourceDir(arg0.latin1(), arg1);
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString arg1 = extractTQString(exec, args, 1);
+ TQString path = KGlobal::dirs ()->findResourceDir(arg0.latin1(), arg1);
return KJS::String( path );
}
case StdDirsImp::saveLocation:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString arg1 = extractTQString(exec, args, 1);
bool arg2 = (args.size() > 2) ? args[2].toBoolean(exec) : true;
- TTQString path = KGlobal::dirs ()->saveLocation(arg0.latin1(), arg1, arg2);
+ TQString path = KGlobal::dirs ()->saveLocation(arg0.latin1(), arg1, arg2);
return KJS::String( path );
}
case StdDirsImp::makeDir:
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
int arg1 = (args.size() > 1) ? args[1].toInteger(exec) : 0755;
bool isOk = KStandardDirs::makeDir(arg0, arg1);
return KJS::Boolean( isOk );
}
case StdDirsImp::exists:
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
bool isOk = KStandardDirs::exists(arg0);
return KJS::Boolean( isOk );
}
case StdDirsImp::realPath:
{
- TTQString arg0 = extractTQString(exec, args, 0);
- TTQString path = KStandardDirs::realPath(arg0);
+ TQString arg0 = extractTQString(exec, args, 0);
+ TQString path = KStandardDirs::realPath(arg0);
return KJS::String( path );
}
case StdDirsImp::currentDirPath:
- return KJS::String(TTQDir::currentDirPath());
+ return KJS::String(TQDir::currentDirPath());
case StdDirsImp::homeDirPath:
- return KJS::String(TTQDir::homeDirPath());
+ return KJS::String(TQDir::homeDirPath());
case StdDirsImp::applicationDirPath:
return KJS::String(qApp->applicationDirPath());
default:
@@ -178,14 +178,14 @@ void StdIconsImp::addBindings( JSFactory *fact, KJS::ExecState *exec, KJS::Obje
}
-KJS::Value StdIconsImp::wrapPixmap(KJS::ExecState *exec, const TTQPixmap &icon)
+KJS::Value StdIconsImp::wrapPixmap(KJS::ExecState *exec, const TQPixmap &icon)
{
return convertToValue(exec, icon);
}
KJS::Value StdIconsImp::call( KJS::ExecState *exec, KJS::Object &/*obj*/, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0); // Name
+ TQString arg0 = extractTQString(exec, args, 0); // Name
int arg1 = extractInt(exec, args, 1); // Size 0, 16, 24, 32, 48, 64, 128
int arg2 = extractInt(exec, args, 2);
// State 0 DefaultState, 1 ActiveState, 2 DisabledState, 3 LastState
@@ -212,7 +212,7 @@ KJS::Value StdIconsImp::call( KJS::ExecState *exec, KJS::Object &/*obj*/, const
}
case StdIconsImp::MimeSourceIcon:
{
- return wrapPixmap( exec, TTQPixmap::fromMimeSource(arg0));
+ return wrapPixmap( exec, TQPixmap::fromMimeSource(arg0));
}
default:
kdWarning() << "StdDirsImp has no method " << id << endl;
diff --git a/kjsembed/builtins/resources.h b/kjsembed/builtins/resources.h
index 45d7dad7..cfd589ce 100644
--- a/kjsembed/builtins/resources.h
+++ b/kjsembed/builtins/resources.h
@@ -87,8 +87,8 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- /** wrap a TTQPixmap **/
- KJS::Value wrapPixmap(KJS::ExecState *exec,const TTQPixmap &icon);
+ /** wrap a TQPixmap **/
+ KJS::Value wrapPixmap(KJS::ExecState *exec,const TQPixmap &icon);
uint id;
JSFactory *jsfact;
};
diff --git a/kjsembed/builtins/saxhandler.cpp b/kjsembed/builtins/saxhandler.cpp
index 50507ff9..ff0334bf 100644
--- a/kjsembed/builtins/saxhandler.cpp
+++ b/kjsembed/builtins/saxhandler.cpp
@@ -23,7 +23,7 @@ namespace KJSEmbed {
namespace BuiltIns {
SaxHandler::SaxHandler( KJS::ExecState *execstate )
- : TTQXmlDefaultHandler(), exec(execstate), error( ErrorNone )
+ : TQXmlDefaultHandler(), exec(execstate), error( ErrorNone )
{
}
@@ -45,7 +45,7 @@ bool SaxHandler::startDocument()
KJS::Identifier funName("startDocument");
if ( !jshandler.hasProperty(exec, funName) )
- return TTQXmlDefaultHandler::startDocument();
+ return TQXmlDefaultHandler::startDocument();
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -66,7 +66,7 @@ bool SaxHandler::endDocument()
KJS::Identifier funName("endDocument");
if ( !jshandler.hasProperty(exec, funName) )
- return TTQXmlDefaultHandler::endDocument();
+ return TQXmlDefaultHandler::endDocument();
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -78,8 +78,8 @@ bool SaxHandler::endDocument()
return ret.toBoolean( exec );
}
-bool SaxHandler::startElement( const TTQString &ns, const TTQString &ln, const TTQString &qn,
- const TTQXmlAttributes &attrs )
+bool SaxHandler::startElement( const TQString &ns, const TQString &ln, const TQString &qn,
+ const TQXmlAttributes &attrs )
{
if ( !jshandler.isValid() ) {
error = ErrorNoHandler;
@@ -88,7 +88,7 @@ bool SaxHandler::startElement( const TTQString &ns, const TTQString &ln, const T
KJS::Identifier funName("startElement");
if ( !jshandler.hasProperty(exec, funName) )
- return TTQXmlDefaultHandler::startElement( ns, ln, qn, attrs );
+ return TQXmlDefaultHandler::startElement( ns, ln, qn, attrs );
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -106,7 +106,7 @@ bool SaxHandler::startElement( const TTQString &ns, const TTQString &ln, const T
return ret.toBoolean( exec );
}
-bool SaxHandler::endElement( const TTQString &ns, const TTQString &ln, const TTQString &qn )
+bool SaxHandler::endElement( const TQString &ns, const TQString &ln, const TQString &qn )
{
if ( !jshandler.isValid() ) {
error = ErrorNoHandler;
@@ -115,7 +115,7 @@ bool SaxHandler::endElement( const TTQString &ns, const TTQString &ln, const TTQ
KJS::Identifier funName("endElement");
if ( !jshandler.hasProperty(exec, funName) )
- return TTQXmlDefaultHandler::endElement( ns, ln, qn );
+ return TQXmlDefaultHandler::endElement( ns, ln, qn );
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -132,7 +132,7 @@ bool SaxHandler::endElement( const TTQString &ns, const TTQString &ln, const TTQ
return ret.toBoolean( exec );
}
-bool SaxHandler::characters( const TTQString &chars )
+bool SaxHandler::characters( const TQString &chars )
{
if ( !jshandler.isValid() ) {
error = ErrorNoHandler;
@@ -141,7 +141,7 @@ bool SaxHandler::characters( const TTQString &chars )
KJS::Identifier funName("characters");
if ( !jshandler.hasProperty(exec, funName) )
- return TTQXmlDefaultHandler::characters( chars );
+ return TQXmlDefaultHandler::characters( chars );
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -156,15 +156,15 @@ bool SaxHandler::characters( const TTQString &chars )
return ret.toBoolean( exec );
}
-TTQString SaxHandler::errorString()
+TQString SaxHandler::errorString()
{
switch( error ) {
case ErrorNoHandler:
- return TTQString("No handler specified");
+ return TQString("No handler specified");
break;
case ErrorNotCallable:
- return TTQString("One of the callbacks of the handler is not callable");
+ return TQString("One of the callbacks of the handler is not callable");
break;
case ErrorNone:
// This only means that no error occured in the JS dispatch, there
@@ -175,7 +175,7 @@ TTQString SaxHandler::errorString()
break;
}
- return TTQXmlDefaultHandler::errorString();
+ return TQXmlDefaultHandler::errorString();
}
} // namespace KJSEmbed::BuiltIns
diff --git a/kjsembed/builtins/saxhandler.h b/kjsembed/builtins/saxhandler.h
index 4a1b1954..5feeef58 100644
--- a/kjsembed/builtins/saxhandler.h
+++ b/kjsembed/builtins/saxhandler.h
@@ -57,12 +57,12 @@ public:
virtual bool startDocument();
virtual bool endDocument();
- virtual bool startElement( const TTQString &ns, const TTQString &ln, const TTQString &qn,
- const TTQXmlAttributes &attrs );
- virtual bool endElement( const TTQString &ns, const TTQString &ln, const TTQString &qn );
- virtual bool characters( const TTQString &chars );
+ virtual bool startElement( const TQString &ns, const TQString &ln, const TQString &qn,
+ const TQXmlAttributes &attrs );
+ virtual bool endElement( const TQString &ns, const TQString &ln, const TQString &qn );
+ virtual bool characters( const TQString &chars );
- virtual TTQString errorString();
+ virtual TQString errorString();
private:
KJS::ExecState *exec;
diff --git a/kjsembed/builtins/stdaction_imp.cpp b/kjsembed/builtins/stdaction_imp.cpp
index d81ead33..aa1c43ed 100644
--- a/kjsembed/builtins/stdaction_imp.cpp
+++ b/kjsembed/builtins/stdaction_imp.cpp
@@ -75,12 +75,12 @@ KJS::Value StdActionImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, cons
return KJS::Null();
// recv, slot, parent, name?
- TTQObject *recv = extractTQObject( exec, args, 0);
+ TQObject *recv = extractTQObject( exec, args, 0);
- TTQString sl = extractTQString( exec, args, 1 );
+ TQString sl = extractTQString( exec, args, 1 );
const char *slc = sl.isNull() ? "" : sl.ascii();
- TTQObject *parentobj = extractTQObject( exec, args, 2 );
+ TQObject *parentobj = extractTQObject( exec, args, 2 );
KActionCollection *parent = parentobj ? dynamic_cast<KActionCollection *>( parentobj ) : 0;
KStdAction::StdAction actid = static_cast<KStdAction::StdAction>(id);
diff --git a/kjsembed/builtins/stddialog_imp.cpp b/kjsembed/builtins/stddialog_imp.cpp
index 122cd300..24c973b0 100644
--- a/kjsembed/builtins/stddialog_imp.cpp
+++ b/kjsembed/builtins/stddialog_imp.cpp
@@ -76,32 +76,32 @@ void StdDialogImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
KJS::Value StdDialogImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, const KJS::List &args )
{
- TTQString arg0 = (args.size() > 0) ? args[0].toString(exec).qstring() : TTQString::null;
- TTQString arg1 = (args.size() > 1) ? args[1].toString(exec).qstring() : TTQString::null;
+ TQString arg0 = (args.size() > 0) ? args[0].toString(exec).qstring() : TQString::null;
+ TQString arg1 = (args.size() > 1) ? args[1].toString(exec).qstring() : TQString::null;
switch( id ) {
case MethodGetOpenFileName:
{
- TTQString s = KFileDialog::getOpenFileName( arg0, arg1 );
+ TQString s = KFileDialog::getOpenFileName( arg0, arg1 );
return KJS::String( s );
}
case MethodGetSaveFileName:
{
- TTQString s = KFileDialog::getSaveFileName( arg0, arg1 );
+ TQString s = KFileDialog::getSaveFileName( arg0, arg1 );
return KJS::String( s );
}
case MethodGetExistingDirectory:
{
- TTQString s = KFileDialog::getExistingDirectory( arg0 );
+ TQString s = KFileDialog::getExistingDirectory( arg0 );
return KJS::String( s );
}
#ifndef QT_ONLY
case MethodGetColor:
{
- TTQColor col;
+ TQColor col;
int res = KColorDialog::getColor( col );
- if ( res == TTQDialog::Accepted )
- return convertToValue( exec, TTQVariant(col) );
+ if ( res == TQDialog::Accepted )
+ return convertToValue( exec, TQVariant(col) );
}
case MethodGetOpenURL:
{
diff --git a/kjsembed/builtins/textstream_imp.cpp b/kjsembed/builtins/textstream_imp.cpp
index de155cfa..d28bb46c 100644
--- a/kjsembed/builtins/textstream_imp.cpp
+++ b/kjsembed/builtins/textstream_imp.cpp
@@ -28,7 +28,7 @@
namespace KJSEmbed {
namespace BuiltIns {
-TextStreamImp::TextStreamImp( KJS::ExecState *exec, int mid, TTQTextStream *textstream )
+TextStreamImp::TextStreamImp( KJS::ExecState *exec, int mid, TQTextStream *textstream )
: JSProxyImp(exec), id(mid), ts(textstream)
{
}
@@ -47,7 +47,7 @@ void TextStreamImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
return;
}
- TTQTextStream *ts = op->toTextStream();
+ TQTextStream *ts = op->toTextStream();
if ( !ts ) {
kdWarning() << "TextStreamImp::addBindings() failed, type is " << op->typeName() << endl;
return;
@@ -73,12 +73,12 @@ void TextStreamImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
KJS::Value TextStreamImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, const KJS::List &args )
{
- TTQString not_readable = i18n( "Attempt to read from a write-only text stream." );
- TTQString not_writable = i18n( "Attempt to write to a read-only text stream." );
+ TQString not_readable = i18n( "Attempt to read from a write-only text stream." );
+ TQString not_writable = i18n( "Attempt to write to a read-only text stream." );
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
- TTQIODevice *dev = ts->device();
+ TQIODevice *dev = ts->device();
KJS::Object err;
switch ( id ) {
@@ -102,7 +102,7 @@ KJS::Value TextStreamImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, con
break;
case MethodReadLine:
if ( dev->isReadable() ) {
- TTQString line = ts->readLine();
+ TQString line = ts->readLine();
if ( line.isNull() )
return KJS::Null();
else
diff --git a/kjsembed/builtins/textstream_imp.h b/kjsembed/builtins/textstream_imp.h
index 7a2bf824..c08470fc 100644
--- a/kjsembed/builtins/textstream_imp.h
+++ b/kjsembed/builtins/textstream_imp.h
@@ -27,7 +27,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TTQTextStream;
+class TQTextStream;
namespace KJSEmbed {
namespace BuiltIns {
@@ -51,7 +51,7 @@ public:
MethodFlush
};
- TextStreamImp( KJS::ExecState *exec, int id, TTQTextStream *ts );
+ TextStreamImp( KJS::ExecState *exec, int id, TQTextStream *ts );
~TextStreamImp();
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
@@ -64,7 +64,7 @@ public:
private:
int id;
- TTQTextStream *ts;
+ TQTextStream *ts;
class TextStreamImpPrivate *d;
};
diff --git a/kjsembed/builtins/qdir_imp.h b/kjsembed/builtins/qdir_imp.h
index ed89ad7c..55c319a5 100644
--- a/kjsembed/builtins/qdir_imp.h
+++ b/kjsembed/builtins/qdir_imp.h
@@ -10,7 +10,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
#include <kjsembed/jsbindingbase.h>
-class TTQDir;
+class TQDir;
/**
* Namespace containing the KJSEmbed library.
@@ -25,7 +25,7 @@ namespace Bindings {
};
}
/**
* Wrapper class for TTQDir methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -157,7 +157,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQDir *instance; // Temp
+ TQDir *instance; // Temp
int mid;
};
@@ -25,7 +25,7 @@ namespace Bindings {
}
/**
- * Wrapper class for TTQDir methods.
+ * Wrapper class for TQDir methods.
*
* @author Richard Moore, rich@kde.org